@@ -45,9 +45,11 @@ MathVariables *math_variables_new(void);
 
 gchar **math_variables_get_names(MathVariables *variables);
 
-void math_variables_set_value(MathVariables *variables, const char *name, const MPNumber *value);
+void math_variables_set(MathVariables *variables, const char *name, const MPNumber *value);
 
-MPNumber *math_variables_get_value(MathVariables *variables, const char *name);
+MPNumber *math_variables_get(MathVariables *variables, const char *name);
+
+void math_variables_delete(MathVariables *variables, const char *name);
 
 G_END_DECLS
 
